#
# spec file for package python-nornir
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2019-2023, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-nornir
Version:        3.4.1
Release:        1.6
Summary:        Network automation framework written in Python
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/nornir-automation/nornir
Source:         https://github.com/nornir-automation/nornir/archive/v%{version}.tar.gz#/nornir-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-importlib-metadata
Requires:       python-mypy_extensions
Requires:       python-ruamel.yaml >= 0.17
# SECTION test requirements
BuildRequires:  %{python_module decorator}
BuildRequires:  %{python_module importlib-metadata}
BuildRequires:  %{python_module mypy_extensions}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests-mock}
BuildRequires:  %{python_module ruamel.yaml >= 0.17}
BuildRequires:  %{python_module typing_extensions >= 4.1}
# /SECTION
BuildArch:      noarch
%python_subpackages

%description
Nornir is a pure Python network automation framework intented to be used
directly from Python.
While most automation frameworks use their own Domain Specific Language (DSL)
which you use to describe what you want to have done, Nornir lets you control
everything from Python.
What Nornir brings to the table is that it takes care of dealing with your
inventory and manages the job of dispatching the tasks you want to run against
your nodes and devices. The framework provides a very simple way to write
plugins if you aren't happy with the ones we ship.

%prep
%setup -q -n nornir-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest --ignore tests/core/test_registered_plugins.py

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitelib}/nornir*

%changelog
* Mon Sep 25 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 3.4.1
  * Fix missing typing_extensions and mypy_extensions dependencies.
* Thu Sep 21 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 3.4.0
  * Added plugins architecture image to plugins docs.
  * Fix wrongly return True when a comparison returns
    NotImplemented.
  * Log number of hosts to run on correctly.
* Tue Jul  5 2022 Daniel García Moreno <dani@danigm.net>
- Update to version 3.3.0
  * Remove not needed dependencies
  * Remove tests that requires nornir-utils
* Wed Mar 17 2021 Matej Cepl <mcepl@suse.com>
- Don't use setup.py from somewhere, but proper poetry toolchain
  (yes, we need full poetry package for poetry.masonry).
* Sat Feb 15 2020 Martin Hauke <mardnh@gmx.de>
- Update o version 2.4.0
  * Netconf connection plugin does not respect ssh config
  * Added napalm_ping.py plugin
  * Replace multiprocessing.dummy with concurrent.futures
  * Ansible Inventory - NornirNoValidInventoryError Exception
  * Minor Typing updates to appease mypy
  * Update to support Netmiko 3.x.x
  * Add netconf plugins
  * Fix KeyError when setting a “False” val in defaults
  * Add Netbox inventory plugin to documentation
  * Add netconf_capabilities plugin
  * Fix netbox unnamed devices
* Mon Oct 14 2019 Martin Hauke <mardnh@gmx.de>
- Add missing buildtime requirement: colorama >= 0.4.1
* Sat Oct 12 2019 Martin Hauke <mardnh@gmx.de>
- Use tarball from github
- Run testsuite
- Add setup.py from pypi. It's not shipped in the github archive
  since upstream uses the poetry package manager.
* Sat Sep 21 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 2.3.0
* Thu Sep 19 2019 Martin Hauke <mardnh@gmx.de>
- Initial package, version 2.2.0
